@@ -112,7 +112,11 @@ class TextBox(Buttons):
                 if self.text:
                     #Iterate over all letters, to find which letter was closest to
                     #the position at which the user clicked
-                    pixel_offset = - self.text_scroll + self.scaled(max(self.border[1] + self.border[2] + round(self.font_size / 4), self.accent_border[1] + self.accent_border[2] + round(self.font_size / 4)), True)
+                    text_width = self.font.size(self.text)[0]
+                    if text_width < self.true_width - 2 * self.scaled(self.text_offset[0]):
+                        pixel_offset = self.AlignX(text_width, self.true_width - 2 * self.scaled(self.text_offset[0]) - 1, self.text_align).left + self.scaled(self.text_offset[0])
+                    else:
+                        pixel_offset = - self.text_scroll + self.scaled(self.text_offset[0])
                     for letter_nr, letter in enumerate(self.text):
                         pixel_length = self.font.size(self.text[:letter_nr + 1])[0]
                         if (pixel_length + pixel_offset) >= pos[0]:
@@ -214,9 +218,10 @@ class TextBox(Buttons):
             text_rect = text_surface.get_rect()
             #Align the text rect
             text_rect = self.AlignY(text_rect, limiter_rect, self.text_align)
-            if text_rect.width <= limiter_rect.width:
+            if text_rect.width < limiter_rect.width:
                 #If the text is smaller than the limiter, perform alignment in the X direction
-                self.AlignX(text_rect, limiter_rect, self.text_align)
+                #Available width -= 1 to account for the cursor potentially being on the right side of the text
+                self.AlignX(text_rect, limiter_rect.width - 1, self.text_align)
             else:
                 #If the text is wider than the limiter, all alignment is taken care of inside text_scroll
                 text_rect.left = - self.text_scroll
@@ -303,6 +308,15 @@ class TextBox(Buttons):
         self.updated = True
 
 
+    @property
+    def text_align(self):
+        return self.__text_align
+    @text_align.setter
+    def text_align(self, value):
+        self.__text_align = value
+        self.updated = True
+
+
     @property
     def text(self):
         return self.__value
